@@ -26,7 +26,7 @@
 #include <qpaintengine.h>
 #endif
 
-#include "qwt_rect.h"
+#include "qwt_clipper.h"
 #include "qwt_math.h"
 #include "qwt_color_map.h"
 #include "qwt_scale_map.h"
@@ -94,8 +94,7 @@ const QRect &QwtPainter::deviceClipRect()
 //! Clip a point array
 QwtPolygon QwtPainter::clip(const QwtPolygon &pa)
 {
-    const QwtRect rect(deviceClipRect());
-    return rect.clip(pa);
+    return QwtClipper::clipPolygon(deviceClipRect(), pa);
 }
 
 #if QT_VERSION < 0x040000 
@@ -184,7 +183,7 @@ void QwtPainter::drawRect(QPainter *painter, int x, int y, int w, int h)
 */
 void QwtPainter::drawRect(QPainter *painter, const QRect &rect) 
 {
-    QRect r = d_metricsMap.layoutToDevice(rect, painter);
+    const QRect r = d_metricsMap.layoutToDevice(rect, painter);
 
     QRect clipRect;
 
@@ -220,19 +219,6 @@ void QwtPainter::drawRect(QPainter *painter, const QRect &rect)
         }
     }
 
-#if QT_VERSION >= 0x040000
-    if ( painter->pen().style() != Qt::NoPen && 
-        painter->pen().color().isValid() )
-    {
-        // Qt4 adds the pen to the rect, Qt3 not.
-        int pw = painter->pen().width();
-        if ( pw == 0 )
-            pw = 1;
-
-        r.setWidth(r.width() - pw);
-        r.setHeight(r.height() - pw);
-    }
-#endif
     painter->drawRect(r);
 }
 
@@ -670,10 +656,6 @@ void QwtPainter::drawColorBar(QPainter *painter,
         const QwtScaleMap &scaleMap, Qt::Orientation orientation,
         const QRect &rect)
 {
-    painter->save();
-
-    QwtPainter::setClipRect(painter, rect);
-
 #if QT_VERSION < 0x040000
     QValueVector<QRgb> colorTable;
 #else
@@ -686,6 +668,15 @@ void QwtPainter::drawColorBar(QPainter *painter,
 
     const QRect devRect = d_metricsMap.layoutToDevice(rect);
 
+    /*
+      We paint to a pixmap first to have something scalable for printing
+      ( f.e. in a Pdf document )
+     */
+      
+    QPixmap pixmap(devRect.size());
+    QPainter pmPainter(&pixmap);
+    pmPainter.translate(-devRect.x(), -devRect.y());
+
     if ( orientation == Qt::Horizontal )
     {
         QwtScaleMap sMap = scaleMap;
@@ -700,12 +691,8 @@ void QwtPainter::drawColorBar(QPainter *painter,
             else
                 c = colorTable[colorMap.colorIndex(interval, value)];
 
-            painter->setBrush(QBrush(c));
-
-            const QRect r(x, devRect.top(), 1, devRect.height());
-            QwtPainter::drawRect(painter, r);
-            painter->setPen(c);
-            painter->drawLine(x, devRect.top(), x, devRect.bottom() - 1);
+            pmPainter.setPen(c);
+            pmPainter.drawLine(x, devRect.top(), x, devRect.bottom());
         }
     }
     else // Vertical
@@ -722,9 +709,10 @@ void QwtPainter::drawColorBar(QPainter *painter,
             else
                 c = colorTable[colorMap.colorIndex(interval, value)];
 
-            painter->setPen(c);
-            painter->drawLine(devRect.left(), y, devRect.right() - 1, y);
+            pmPainter.setPen(c);
+            pmPainter.drawLine(devRect.left(), y, devRect.right(), y);
         }
     }
-    painter->restore();
+    pmPainter.end();
+    painter->drawPixmap(devRect, pixmap);
 }
